@@ -22,6 +22,7 @@ our @EXPORT_OK = qw/
 	get_bKGD
 	get_bit_depth
 	get_cHRM
+	get_cHRM_XYZ
 	get_channels
 	get_color_type
 	get_compression_buffer_size
@@ -35,6 +36,7 @@ our @EXPORT_OK = qw/
 	get_oFFs
 	get_pCAL
 	get_pHYs
+	get_palette_max
 	get_row_pointers
 	get_rowbytes
 	get_rows
@@ -50,6 +52,7 @@ our @EXPORT_OK = qw/
 	get_valid
 	init_io
 	libpng_supports
+	permit_mng_features
 	read_from_scalar
 	read_image
 	read_info
@@ -59,8 +62,11 @@ our @EXPORT_OK = qw/
 	scalar_as_input
 	set_IHDR
 	set_PLTE
+	set_alpha_mode
 	set_bKGD
+	set_bgr
 	set_cHRM
+	set_cHRM_XYZ
 	set_compression_buffer_size
 	set_compression_level
 	set_compression_mem_level
@@ -70,18 +76,24 @@ our @EXPORT_OK = qw/
 	set_crc_action
 	set_eXIf
 	set_expand
+	set_expand_16
 	set_filler
 	set_filter
 	set_gAMA
+	set_gamma
 	set_gray_to_rgb
 	set_hIST
 	set_iCCP
 	set_image_data
+	set_invert_alpha
+	set_invert_mono
 	set_keep_unknown_chunks
 	set_oFFs
 	set_pCAL
 	set_pHYs
 	set_packing
+	set_packswap
+	set_palette_to_rgb
 	set_rgb_to_gray
 	set_rgb_to_gray_fixed
 	set_row_pointers
@@ -90,7 +102,11 @@ our @EXPORT_OK = qw/
 	set_sCAL
 	set_sPLT
 	set_sRGB
+	set_scale_16
 	set_strip_16
+	set_strip_alpha
+	set_swap
+	set_swap_alpha
 	set_tIME
 	set_tRNS
 	set_tRNS_pointer
@@ -103,6 +119,7 @@ our @EXPORT_OK = qw/
 	set_unknown_chunks
 	set_user_limits
 	set_verbosity
+	shift
 	sig_cmp
 	split_alpha
 	text_compression_name
@@ -123,7 +140,7 @@ our %EXPORT_TAGS = (
 );
 
 require XSLoader;
-our $VERSION = '0.51_01';
+our $VERSION = '0.52_01';
 
 XSLoader::load('Image::PNG::Libpng', $VERSION);
 
@@ -195,6 +212,8 @@ cHRM => 1,
 
 
 
+
+
 gAMA => 1,
 
 hIST => 1,
